@@ -144,8 +144,6 @@ class AccountingDataParser(object):
     Base Accounting datas parser
     """
     _supported_extensions = ('csv', 'slk')
-    quotechar = '"'
-    delimiter = ','
     encoding = 'utf-8'
 
     # To be filled in subclasses
@@ -215,9 +213,9 @@ class AccountingDataParser(object):
         :returns: An iterator of sheet lines as lists
         """
         with open(self.file_path, encoding=self.encoding) as fbuf:
-            for line in csv.reader(
-                fbuf, quotechar=self.quotechar, delimiter=self.delimiter,
-            ):
+            dialect = csv.Sniffer().sniff(fbuf.read(1024))
+            fbuf.seek(0)
+            for line in csv.reader(fbuf, dialect):
                 yield line
 
     def _stream_datas(self):
@@ -261,7 +259,7 @@ class AccountingDataParser(object):
         :param list line_datas: List of datas found in the line
         :returns: An instance of AccountingOperation
         """
-        raise NotImplemented(
+        raise NotImplementedError(
             u"_build_operation should be implemented in subclasses"
         )
 
@@ -288,9 +286,10 @@ class AccountingDataParser(object):
 
         :rtype: bool
         """
-        query = DBSESSION().query(AccountingOperationUpload.id)
-        query = query.filter_by(md5sum=self._file_datas['md5sum'])
-        return query.count() > 0
+        return False
+        # query = DBSESSION().query(AccountingOperationUpload.id)
+        # query = query.filter_by(md5sum=self._file_datas['md5sum'])
+        # return query.count() > 0
 
     def _get_existing_operation_ids(self):
         """
