@@ -8,11 +8,14 @@ from celery.utils.log import get_task_logger
 
 JOB_RETRIEVE_ERROR = u"We can't retrieve the job {jobid}, the task will not \
 be run"
+TASK_RETRIEVE_ERROR = u"We can't retrieve the task {}, the task will not \
+be run"
 
 
 def get_logger(name=""):
     return get_task_logger("celery." + name)
 
+
 logger = get_logger(__name__)
 
 
@@ -37,11 +40,11 @@ def get_job(celery_request, job_model, job_id):
     logger.debug("Retrieving a job with id : {0}".format(job_id))
     from endi_base.models.base import DBSESSION
 
-    # We try to get tje job back, waiting for the current request to be finished
-    # : since we use a transaction manager, the delay call launched in a view is
-    # done before the job  element is commited to the bdd (at the end of the
-    # request) if we query for the job too early, the session will not be able
-    # to retrieve the newly created job
+    # We try to get tje job back, waiting for the current request to be
+    # finished : since we use a transaction manager, the delay call launched in
+    # a view is done before the job  element is commited to the bdd (at the end
+    # of the request) if we query for the job too early, the session will not
+    # be able to retrieve the newly created job
     current_time = 0
     job = None
     while current_time <= TIMEOUT and job is None:
@@ -66,6 +69,52 @@ def get_job(celery_request, job_model, job_id):
     return job
 
 
+def get_task(task_id):
+    """
+    Return the current executed job (in endi's sens)
+
+    :param obj celery_request: The current celery request object
+    :param int task_id: The id of the Task object
+
+    :returns: The current Task
+    :raises sqlalchemy.orm.exc.NoResultFound: If the Task could not be found
+    """
+    logger.debug("Retrieving a task with id : {0}".format(task_id))
+    from endi_base.models.base import DBSESSION
+    from endi.models.task import (
+        Task,
+        Invoice,
+        CancelInvoice,
+    )
+
+    # We try to get tje job back, waiting for the current request to be
+    # finished : since we use a transaction manager, the delay call launched in
+    # a view is done before the job  element is commited to the bdd (at the end
+    # of the request) if we query for the job too early, the session will not
+    # be able to retrieve the newly created job
+    current_time = 0
+    task = None
+    while current_time <= TIMEOUT and task is None:
+        try:
+            task = DBSESSION().query(Task).get(task_id)
+            if task is not None and isinstance(task, (Invoice, CancelInvoice)):
+                if task.official_number is None:
+                    logger.error(u"Task has no number yet")
+                    task = None
+                    raise NoResultFound
+        except NoResultFound:
+            transaction.abort()
+            transaction.begin()
+            logger.debug(" -- No job found")
+            logger.exception(TASK_RETRIEVE_ERROR.format(task_id))
+
+        if task is None:
+            time.sleep(INTERVAL)
+            current_time += INTERVAL
+
+    return task
+
+
 def _record_running(job):
     """
     Record that a job is running
